@@ -687,8 +687,8 @@ def test_pyoxynet(input_df=[], n_inputs=6, past_points=40, model='CNN', plot=Tru
     out_dict['VT2']['time'] = {}
 
     # FIXME: hard coded
-    VT1_index = int(out_df[(out_df['p_hv'] <= out_df['p_md'])].index[-1] + past_points/2)
-    VT2_index = int(out_df[(out_df['p_hv'] >= out_df['p_sv']) & (out_df['p_hv'] > out_df['p_md'])].index[-1] + past_points/2)
+    VT1_index = int(out_df[(out_df['p_hv'] <= out_df['p_md'])].index[-1])
+    VT2_index = int(out_df[(out_df['p_hv'] >= out_df['p_sv']) & (out_df['p_hv'] > out_df['p_md'])].index[-1])
 
     out_dict['VT1']['time'] = df.iloc[VT1_index]['time']
     out_dict['VT2']['time'] = df.iloc[VT2_index]['time']
@@ -698,7 +698,7 @@ def test_pyoxynet(input_df=[], n_inputs=6, past_points=40, model='CNN', plot=Tru
 
     return out_df, out_dict
 
-def create_probabilities(duration=600, VT1=320, VT2=460, training=True, normalization=True, resting = True):
+def create_probabilities(duration=600, VT1=320, VT2=460, training=True, normalization=False, resting = True, resting_duration=60):
     """Creates the probabilities of being in different intensity domains
 
     These probabilities are then sent to the CPET generator and they are used ot generate CPET vars that can replicate those probabilities
@@ -721,7 +721,7 @@ def create_probabilities(duration=600, VT1=320, VT2=460, training=True, normaliz
     t = np.arange(1, duration + 1)
 
     if resting == True:
-        step_1 = 60
+        step_1 = resting_duration
         smooth_lambda = [duration*2, duration*2, duration*2]
     else:
         # no resting is included
@@ -758,13 +758,6 @@ def create_probabilities(duration=600, VT1=320, VT2=460, training=True, normaliz
     p_hF = optimal_filter(t, p_hF, 50)
     p_sF = optimal_filter(t, p_sF, 100)
 
-    if training:
-        p_mF = p_mF + np.random.randn(len(t)) / 18
-        p_hF = p_hF + np.random.randn(len(t)) / 18
-        p_sF = p_sF + np.random.randn(len(t)) / 18
-    else:
-        pass
-
     if normalization:
         p_mF = np.interp(p_mF, (p_mF.min(), p_mF.max()), (0, 1))
         p_hF = np.interp(p_hF, (p_hF.min(), p_hF.max()), (0, 1))
@@ -772,6 +765,13 @@ def create_probabilities(duration=600, VT1=320, VT2=460, training=True, normaliz
     else:
         pass
 
+    if training:
+        p_mF = p_mF + np.random.randn(len(t)) / 18
+        p_hF = p_hF + np.random.randn(len(t)) / 18
+        p_sF = p_sF + np.random.randn(len(t)) / 18
+    else:
+        pass
+
     return p_mF, p_hF, p_sF
 
 def random_walk(length=1, scale_factor=1, variation=1):
@@ -807,7 +807,7 @@ def generate_CPET(generator,
                   noise_factor=0,
                   resting=False,
                   training=True,
-                  normalization=True):
+                  normalization=False):
     """Actually generates the CPET file
 
     Parameters:
